pymodaq_plugins_newport (Newport Instruments)
#############################################

.. image:: https://img.shields.io/pypi/v/pymodaq_plugins_newport.svg
   :target: https://pypi.org/project/pymodaq_plugins_newport/
   :alt: Latest Version

.. image:: https://readthedocs.org/projects/pymodaq/badge/?version=latest
   :target: https://pymodaq.readthedocs.io/en/stable/?badge=latest
   :alt: Documentation Status

.. image:: https://github.com/CEMES-CNRS/pymodaq_plugins_newport/workflows/Upload%20Python%20Package/badge.svg
    :target: https://github.com/CEMES-CNRS/pymodaq_plugins_newport

PyMoDAQ plugin for instruments from Newport (Conex, ESP100,...)


Authors
=======

* Sebastien J. Weber

Instruments
===========
Below is the list of instruments included in this plugin

Actuators
+++++++++

* **Conex**: Piezo actuators from the CONEX-AGAP series"
* **Newport_ESP100**: ESP100 motion controllers
